@@ -1,6 +1,7 @@
 from prophets import Isaiah, TwitterParser, Elijiah
 import sys
 from pprint import pprint
+from datetime import datetime, timedelta
 
 if __name__ == "__main__":
     print(f"Abraham Version: {open('version').read().strip()}")
@@ -10,11 +11,16 @@ if __name__ == "__main__":
     # """
     darthvader = Isaiah(
         news_source="newsapi",
-        newsapi_key="3530e04f04034a85a0ebf4d925c83c69",
+        newsapi_key=open("keys/newsapi-public").read().strip(),
         bearer_token=open("keys/twitter-bearer-token").read().strip(),
     )  # splitting means that it recursively splits a large text into sentences and analyzes each individually
 
-    scores = darthvader.summary(*args)  # latest date to get news from
+    newest = datetime.now()
+    oldest = newest - timedelta(days=1)  # datetime one week ago = the finish line
+
+    scores = darthvader.summary_interval(
+        *args, oldest, newest
+    )  # latest date to get news from
     print("Total\n--")
     pprint(scores)
 
